@@ -1,6 +1,7 @@
 """This module contains the InstaClient class"""
 
 # IMPORT UTILITIES, DEPENDENCIES & MODELS
+from instaclient.instagram.comment import Comment
 from instaclient.client import *
 from instaclient.utilities.utilities import *
 
@@ -15,7 +16,7 @@ class InstaClient(Auth, Interactions, Scraper):
     CHROMEDRIVER=1
     LOCAHOST=1
     WEB_SERVER=2
-    def __init__(self, driver_type: int=CHROMEDRIVER, host_type:int=LOCAHOST, driver_path=None, init_driver=False, logger:logging.Logger=None, debug=False, error_callback=None, localhost_headless=False, proxy=None, scraperapi_key=None):
+    def __init__(self, driver_type: int=CHROMEDRIVER, host_type:int=LOCAHOST, driver_path=None, connect=False, logger:logging.Logger=None, debug=False, error_callback=None, localhost_headless=False, proxy=None):
         """
         Create an `InstaClient` object to access the instagram website.
 
@@ -43,15 +44,12 @@ class InstaClient(Auth, Interactions, Scraper):
         if error_callback or debug:
             if not callable(error_callback):
                 raise InvalidErrorCallbackError()
-        self.error_callback = error_callback
+        self.error_callback = error_callback 
         self.localhost_headless = localhost_headless
         self.proxy = proxy
-        self.scraperapi_key = scraperapi_key
-        self.logged_in = False
         self.driver = None
         self.username = None
         self.password = None
-        self.threads = []
 
         global LOGGER
         if logger:
@@ -60,48 +58,98 @@ class InstaClient(Auth, Interactions, Scraper):
         if debug and not logger:
            LOGGER.setLevel(logging.DEBUG)
 
-        if init_driver:
-            self._init_driver(func='__init__')
+        if connect:
+            self._connect(func='__init__')
+
+    # CLIENT PROPERTIES
+    @property
+    def logged_in(self) -> bool:
+        """
+        logged_in: Checks whether the client is currently logged in to Instagram.
+
+        Returns:
+            bool: True if `driver` is open and user is logged into Instagram.
+        """
+        if self.driver:
+            if self.username and self.password:
+                url = self.driver.current_url
+                if 'https://www.instagram.com/' in url and ClientUrls.LOGIN_URL not in url:
+                    return True
+        return False
+
+    @property
+    def threads(self) -> Optional[list]:
+        """
+        threads: gets all the threads created and controlled by the client. All such threads include `instaclient` in their names.
+
+        Returns:
+            Optional[list]: A list of all sub-threads created and controlled by the client. Returns `None` if no thread is found.
+        """
+        running = list()
+        for thread in threading.enumerate(): 
+            if thread is not threading.main_thread():
+                running.append(thread)
+        
+        if len(running) < 1:
+            return None
+        else:
+            return running
+
+
+
+    # DRIVER METHODS
+    def connect(self: 'InstaClient', login=False, retries=0, func=None):
+        return super()._connect(login=login, retries=retries, func=func)
+
+    def disconnect(self: 'InstaClient'):
+        return super()._disconnect()
+
 
 
     # AUTH
-    def login(self: 'InstaClient', username: str, password: str, check_user: bool=True, _discard_driver: bool=False):
-        return super()._login(username, password, check_user=check_user, _discard_driver=_discard_driver)
+    def login(self: 'InstaClient', username: str, password: str, check_user: bool=True):
+        return super()._login(username, password, check_user=check_user)
+
 
     def resend_security_code(self):
         return super()._resend_security_code()
 
-    def input_security_code(self, code: int, _discard_driver: bool=False):
-        return super()._input_security_code(code, _discard_driver=_discard_driver)
 
-    def input_verification_code(self, code: int, _discard_driver: bool=False):
-        return super()._input_verification_code(code, _discard_driver=_discard_driver)
+    def input_security_code(self, code: int):
+        return super()._input_security_code(code)
 
-    def logout(self: 'InstaClient', _discard_driver: bool=False):
-        return super()._logout(_discard_driver=_discard_driver)
+
+    def input_verification_code(self, code: int):
+        return super()._input_verification_code(code)
+
+
+    def logout(self: 'InstaClient', disconnect:bool=True):
+        return super()._logout(disconnect=disconnect)
     
 
 
     # CHECKERS
-    def check_status(self: 'InstaClient', _discard_driver: bool=False) -> bool:
-        return super()._check_status(_discard_driver=_discard_driver)
+    def check_status(self: 'InstaClient') -> bool:
+        return super()._check_status()
     
-    def is_valid_user(self: 'InstaClient', user: str, nav_to_user: bool=True, _discard_driver: bool=False) -> bool:
-        return super()._is_valid_user(user, nav_to_user=nav_to_user, _discard_driver=_discard_driver)
+
+    def is_valid_user(self: 'InstaClient', user: str, nav_to_user: bool=True) -> bool:
+        return super()._is_valid_user(user, nav_to_user=nav_to_user)
+
 
    
     # SCRAPING
     def get_notifications(self: 'InstaClient', types: Optional[list]=None, count: Optional[int]=None) -> Optional[list]:
         return super()._scrape_notifications(types=types, count=count)
 
+
     def get_profile(self: 'InstaClient', username: str, context: bool=True) -> Optional[Profile]:
         return super()._scrape_profile(username, context=context)
 
-    def get_user_images(self, user: str, _discard_driver: bool=False):
-        return super()._scrape_user_images(user, _discard_driver=_discard_driver)
 
-    def get_followers(self, user: str, count: int, check_user:bool=True, _discard_driver:bool=False, callback_frequency: int=100, callback=None, **callback_args) -> Optional[list]:
-        return super()._scrape_followers(user, count, check_user=check_user, _discard_driver=_discard_driver, callback_frequency=callback_frequency, callback=callback, **callback_args)
+    def get_followers(self, user: str, count: int, check_user:bool=True, callback_frequency: int=100, callback=None, **callback_args) -> Optional[list]:
+        return super()._scrape_followers(user, count, check_user=check_user, callback_frequency=callback_frequency, callback=callback, **callback_args)
+
 
     def get_hashtag(self: 'InstaClient', tag: str) -> Optional[Hashtag]:
         return super()._scrape_tag(tag, self.username)
@@ -109,21 +157,39 @@ class InstaClient(Auth, Interactions, Scraper):
     
 
     # INTERACTIONS
-    def follow(self, user: str, nav_to_user: bool=True, _discard_driver: bool=False):
-        return super()._follow_user(user, nav_to_user=nav_to_user, _discard_driver=_discard_driver)
+    def follow(self, user: str, nav_to_user: bool=True):
+        return super()._follow_user(user, nav_to_user=nav_to_user)
 
-    def unfollow(self, user: str, nav_to_user:bool=True, check_user:bool=True, _discard_driver: bool=False):
-        return super()._unfollow_user(user, nav_to_user=nav_to_user, check_user=check_user, _discard_driver=_discard_driver)
 
-    def send_dm(self, user: str, message: str, _discard_driver: bool=False):
-        return super()._send_dm(user, message, _discard_driver=_discard_driver)
+    def unfollow(self, user: str, nav_to_user:bool=True, check_user:bool=True):
+        return super()._unfollow_user(user, nav_to_user=nav_to_user, check_user=check_user)
+
+
+    def send_dm(self, user: str, message: str):
+        return super()._send_dm(user, message)
+
+
+    def comment_post(self, shortcode: str, text: str) -> Optional[Comment]:
+        result = super()._comment_on_post(shortcode, text)
+        # Return Comment Object
+        return self._find_comment(shortcode, self.username, text)
+
+
+    def like_post(self, shortcode: str) -> Optional[Post]:
+        if super()._like_post(shortcode):
+            return self._scrape_post(shortcode)
+        else:
+            return None
+
+
+    def like_user_posts(self, user: str, n_posts: int, like: bool=True):
+        return super()._like_latest_posts(user, n_posts, like=like)
 
-    def like_user_posts(self, user: str, n_posts: int, like: bool=True, _discard_driver: bool=False):
-        return super()._like_latest_posts(user, n_posts, like=like, _discard_driver=_discard_driver)
 
     def like_feed_posts(self, count:int):
         return super()._like_feed_posts(count)
 
+
     def scroll(self, mode:int=Interactions.PAGE_DOWN_SCROLL, size:int=500, times:int=1, interval:int=3):
         return super()._scroll(mode=mode, size=size, times=times, interval=interval)
 
