@@ -22,10 +22,3 @@ import random
         l.setLevel(loglevel)
         l.handler_set = True
     return l   """
-
-
-def get_url(url, scraperapi_key:str=None):
-    if scraperapi_key:
-        return f'http://api.scraperapi.com?api_key={scraperapi_key}&url={url}'
-    else:
-        return url
